Page 43 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 43

Home

    the

    as the Jacobin Clubs. These clubs provided the
    leadership for the events of the French Revolution.

    In the beginning and throughout the Revolution, a
    campaign of vilification was carried out against the King
    and Queen, the priests and nobles. These vilifications
    took the part of both written slanders and oral harangues
    calculated to stir up class hatred among the people. This
    form of propaganda was simply the implementation of
    the big lie technique.

    In addition to propaganda, it was necessary to create
    a crisis to contribute to the restlessness of the people.
    This was accomplished by the agents of the Duke of
    Orleans buying up the grain supplies and withholding
    them from the people. By this means the threat of famine
    faced the people and the cry of "bread" was added to the
    cry of liberty and equality. To add to the agitation of the
    people, the scarcity of grain was blamed on the King and
    Nobles as monopolizers. Throughout the Revolution this

    tactic — of always blaming your enemy for what you are
    doing — was used.
    But in order to start the blood of the revolution

    flowing it was necessary to go a step farther, the hiring
    of criminals and ruffians. These brigands from the South
    of France and Italy, known as the Marseillais, began
    flocking into Paris in the spring of 1789. Men of ferrous
    appearance, they carried thick knotted sticks and made
    up the hard core of the major uprisings that were to
    follow.

    38

    The Secret Side of History

    as the Jacobin Clubs.

    These clubs